@@ -802,7 +802,10 @@ verify_inode (FILE * fp, GLog * glog) {
   glog->inode = fdstat.st_ino;
 }
 
-/* Process appended log data */
+/* Process appended log data
+ *
+ * If nothing changed, 1 is returned.
+ * If log file changed, 0 is returned. */
 static int
 perform_tail_follow (GLog * glog) {
   FILE *fp = NULL;
@@ -983,10 +986,11 @@ term_tail_logs (Logs * logs) {
   int i;
 
   for (i = 0; i < logs->size; ++i) {
-    if (perform_tail_follow (&logs->glog[i]) == 0) {
-      offset = *logs->processed - logs->offset;
-      render_screens (offset);
-    }
+    if (perform_tail_follow (&logs->glog[i]) != 0)
+      continue;
+
+    offset = *logs->processed - logs->offset;
+    render_screens (offset);
     if (nanosleep (&ts, NULL) == -1 && errno != EINTR) {
       FATAL ("nanosleep: %s", strerror (errno));
     }
@@ -1012,7 +1016,7 @@ get_keys (Logs * logs) {
         quit = 0;
         break;
       }
-      if (collapse_current_module ())
+      if (collapse_current_module () == 0)
         render_screens (offset);
       break;
     case KEY_F (1):
@@ -1232,7 +1236,10 @@ init_processing (void) {
   /* perform some additional checks before parsing panels */
   verify_panels ();
   /* initialize storage */
+  pthread_mutex_lock (&parsing_spinner->mutex);
   parsing_spinner->label = "SETTING UP STORAGE";
+  pthread_mutex_unlock (&parsing_spinner->mutex);
+
   init_storage ();
   insert_methods_protocols ();
   set_spec_date_format ();
