@@ -134,6 +134,15 @@ static GHTML htmldef[] = {
     {CHART_VBAR, hits_bw_plot, 0, 1, NULL, NULL},
   }},
 #endif
+  {MIME_TYPE, 1, print_metrics, {
+    {CHART_VBAR, hits_visitors_plot, 0, 1, NULL, NULL},
+    {CHART_VBAR, hits_bw_plot, 0, 1, NULL, NULL},
+  }},
+  {TLS_TYPE, 1, print_metrics, {
+    {CHART_VBAR, hits_visitors_plot, 0, 1, NULL, NULL},
+    {CHART_VBAR, hits_bw_plot, 0, 1, NULL, NULL},
+  }},
+
 };
 /* *INDENT-ON* */
 
