@@ -434,13 +434,15 @@ clean:
  * On success, the 1 is returned. */
 static int
 verify_static_content (const char *req) {
-  const char *nul = req + strlen (req);
+  const char *nul = NULL;
   const char *ext = NULL, *pch = NULL;
   int elen = 0, i;
 
-  if (strlen (req) < conf.static_file_max_len)
+  if ((req == NULL) || (*req == '\0'))
     return 0;
 
+  nul = req + strlen (req);
+
   for (i = 0; i < conf.static_file_idx; ++i) {
     ext = conf.static_files[i];
     if (ext == NULL || *ext == '\0')
@@ -454,7 +456,7 @@ verify_static_content (const char *req) {
       continue;
     }
 
-    if (!strncasecmp (nul - elen, ext, elen))
+    if (nul - req > elen && !strncasecmp (nul - elen, ext, elen))
       return 1;
   }
 
@@ -1494,7 +1496,7 @@ is_static (const char *req) {
  * If the status code is within the ignore-array, 1 is returned. */
 static int
 ignore_status_code (const char *status) {
-  if (conf.ignore_status_idx == 0)
+  if (!status || conf.ignore_status_idx == 0)
     return 0;
 
   if (str_inarray (status, conf.ignore_status, conf.ignore_status_idx) != -1)
@@ -1700,7 +1702,7 @@ parse_json_specifier (void *ptr_data, char *key, char *str) {
   char *spec = NULL;
   int ret = 0;
 
-  if (!str)
+  if (!key || !str)
     return 0;
   /* empty JSON value, e.g., {method: ""} */
   if (0 == strlen (str))
